/*
	SAVEPIC.C - Saves graphics picture generated by RANDY.C
	File format:

	position

	  1		minimum x - upper left corner of image
	  2		minimum y - upper left corner of image
	  3		maximum x - lower right corner of image
	  4		maximum y - lower right corner of image

	  5		# of colors in palette
	  6		1st color in palette
	  7		2nd color in palette
	  .             .
	  .             .
	  n		last color in palette

	  n+1		value of pixel at (minx, miny)
	  n+2		value of pixel at (minx+1, miny)
	  .		.
	  .		.
	  last		value of pixel at (maxx, maxy)
*/

#include <stdio.h>
#include <graphics.h>


int savepic(int minx, int miny, int maxx, int maxy, char *filename)
{
  int	i,x,y,count=0,color,oldcolor;
  FILE	*stream;
  struct palettetype	pal;

  if ((stream=fopen(filename,"wb"))==NULL)
    return 1;

  /* store screen coordinates */
  putc(minx,stream);
  putc(miny,stream);
  putc(maxx,stream);
  putc(maxy,stream);

  /* store color palette info */
  getpalette(&pal);
  putc(pal.size,stream);
  for(i=0;i<pal.size;i++)
    putc(pal.colors[i],stream);

  /* store value of each pixel */
  for(y=miny;y<=maxy;y++)
    for(x=minx;x<=maxx;x++)
    {
      color=getpixel(x,y);
      if(count==0)
      {
	oldcolor=color;
	count=1;
      }
      else /* count!=0 */
	if(color==oldcolor)
	  ++count;
	else /* start of new color */
	{
	  putc(oldcolor,stream);	/* write color to file */
	  putc(count,stream);		/* write # of pixels in this color */
	  count=0;
	}
    }
  if(count!=0)
  {
    putc(oldcolor,stream);
    putc(count,stream);
  }

  fclose(stream);
  return 0;
}
